====
Seep
====

``seep`` is an experimental data coersion and extraction language built to be
used alongside `JSON Schema <http://json-schema.org>`_.

It is currently in the planning stages and could use your help.

Please feel free to open an `issue ticket
<https://github.com/Julian/Seep/issues>`_ or edit a `Wiki page
<https://github.com/Julian/Seep/wiki>`_ if you have ideas.
